@@ -1,6 +1,6 @@
 # ANALYSIS Utilities/"Calculate descriptive statistics" (Calculates basic descriptive statistics for all genes.
 # These include parametric and non-parametric location and spread descriptives.)
-# INPUT GENE_EXPRS normalized.tsv, GENERIC phenodata.tsv OUTPUT descr-stats.tsv, descriptives.tsv
+# INPUT GENE_EXPRS normalized.tsv OUTPUT descr-stats.tsv, descriptives.tsv
 # PARAMETER calculate.descriptives.for [genes, chips] DEFAULT genes (Descriptive statistics are calculated for...)
 
 
@@ -39,8 +39,8 @@ riqr<-apply(X=dat2, MARGIN=1, FUN=IQR)
 # Saving the results
 if(calculate.descriptives.for=="chips") {
    write.table(data.frame(rownames(dat2), average=rmean, median=rmedian, sd=rsd, cv=rcv, st.exp=rstexp, min=rmin, max=rmax, range=rrange, iqr=riqr), file="descr-stats.tsv", sep="\t", row.names=T, col.names=T, quote=F)
+   write.table(data.frame(rownames(dat2), chip.average=rmean, chip.median=rmedian, chip.sd=rsd, chip.cv=rcv, chip.st.exp=rstexp, chip.min=rmin, chip.max=rmax, chip.range=rrange, chip.iqr=riqr), file="descriptives.tsv", sep="\t", row.names=T, col.names=T, quote=F)
 } else {
    write.table(data.frame(dat, average=rmean, median=rmedian, sd=rsd, cv=rcv, st.exp=rstexp, min=rmin, max=rmax, range=rrange, iqr=riqr), file="descr-stats.tsv", sep="\t", row.names=T, col.names=T, quote=F)
    write.table(data.frame(chip.average=rmean, chip.median=rmedian, chip.sd=rsd, chip.cv=rcv, chip.st.exp=rstexp, chip.min=rmin, chip.max=rmax, chip.range=rrange, chip.iqr=riqr), file="descriptives.tsv", sep="\t", row.names=T, col.names=T, quote=F)
-
 }
