@@ -1,5 +1,5 @@
 # ANALYSIS Visualisation/"Histogram" (Creates a histogram for every chip using normalized data.)
-# INPUT GENE_EXPRS normalized.tsv OUTPUT histogram.png
+# INPUT GENE_EXPRS normalized.tsv, GENERIC phenodata.tsv OUTPUT histogram.png
 # PARAMETER image.width INTEGER FROM 200 TO 3200 DEFAULT 600 (Width of the plotted network image)
 # PARAMETER image.height INTEGER FROM 200 TO 3200 DEFAULT 600 (Height of the plotted network image)
 
@@ -15,14 +15,16 @@ h<-image.height
 file<-c("normalized.tsv")
 dat<-read.table(file, header=T, sep="\t", row.names=1)
 
+# Loads phenodata
+phenodata<-read.table("phenodata.tsv", header=T, sep="\t")
+
 # Separates expression values and flags
 calls<-dat[,grep("flag", names(dat))]
 dat2<-dat[,grep("chip", names(dat))]
-colnames(dat2)<-gsub("chip.(.+)", "\\1", colnames(dat2)[grep("chip", colnames(dat2))])
 
 # Draws the histograms
 s<-ceiling(sqrt(ncol(dat2)))
-titles<-colnames(dat2)
+titles<-gsub(" ", "", phenodata$description)
 
 bitmap(file="histogram.png", width=w/72, height=h/72)
 par(mfrow=c(s,s))
